@@ -1,7 +1,7 @@
 package Perinci::Examples;
 
-our $DATE = '2016-06-02'; # DATE
-our $VERSION = '0.73'; # VERSION
+our $DATE = '2016-10-25'; # DATE
+our $VERSION = '0.74'; # VERSION
 
 use 5.010001;
 use strict;
@@ -377,7 +377,7 @@ _
             pos => 0,
             description => <<'_',
 
-A completion library (like `Perinci::Sub::Complete`) can generate a list of
+A completion library (like <pm:Perinci::Sub::Complete>) can generate a list of
 completion from the low end to the high end of the range, as long as it is not
 too long.
 
@@ -494,7 +494,7 @@ it will complete from any `in` value, but in:
 
 it can exclude `apple` from the completion candidate.
 
-Currently the completion library `Perinci::Sub::Complete` does not do this
+Currently the completion library <pm:Perinci::Sub::Complete> does not do this
 though. Perhaps there can be an option to toggle this behavior.
 
 _
@@ -599,11 +599,11 @@ $SPEC{merge_hash} = {
 This function can be used to test passing nonscalar (hash) arguments.
 
 This function also tests the `x.perinci.sub.wrapper.disable_validate_args`
-attribute so that `Perinci::Sub::Wrapper` does not generate argument validation
-code in the wrapper. Note that by adding `# VALIDATE_ARG` in the source code,
-the Dist::Zilla::Plugin::Rinci::Wrap already generates and embeds argument
-validation code in the source code, so duplication is not desired, thus the
-attribute.
+attribute so that <pm:Perinci::Sub::Wrapper> does not generate argument
+validation code in the wrapper. Note that by adding `# VALIDATE_ARG` in the
+source code, the <pm:Dist::Zilla::Plugin::Rinci::Wrap> plugin already generates
+and embeds argument validation code in the source code, so duplication is not
+desired, thus the attribute.
 
 _
     args => {
@@ -664,8 +664,8 @@ $SPEC{undescribed_args} = {
     summary => 'This function has several undescribed args',
     description => <<'_',
 
-Originally added to see how peri-func-usage or `Perinci::To::Text` will display
-the usage or documentation for this function.
+Originally added to see how peri-func-usage or <pm:Perinci::To::Text> will
+display the usage or documentation for this function.
 
 _
     args => {
@@ -790,7 +790,7 @@ $SPEC{gen_sample_data} = {
     summary => "Generate sample data of various form",
     description => <<'_',
 
-This function is first written to test `Perinci::CmdLine::Lite`'s text
+This function is first written to test <pm:Perinci::CmdLine::Lite>'s text
 formatting rules.
 
 _
@@ -922,8 +922,8 @@ $SPEC{test_result_naked} = {
 This function's metadata sets `result_naked` to true. This means function
 returns just the value (e.g. `42`) and not with envelope (e.g. `[200,"OK",42]`).
 However, when served over network Riap protocol, the function wrapper
-`Perinci::Sub::Wrapper` can generate an envelope for the result, so the wrapped
-function wil still return `[200,"OK",42]`.
+<pm:Perinci::Sub::Wrapper> can generate an envelope for the result, so the
+wrapped function wil still return `[200,"OK",42]`.
 
 _
     args => {
@@ -1040,7 +1040,7 @@ $SPEC{multi_status} = {
 
 This function might return 200, 207, or 500, randomly. It will set result
 metadata property `results` to contain per-item results. For more details, see
-the corresponding specification in `results` property in `Rinci::resmeta`.
+the corresponding specification in `results` property in <pod:Rinci::resmeta>.
 
 _
     args => {
@@ -1074,7 +1074,7 @@ Perinci::Examples - Various examples of Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.73 of Perinci::Examples (from Perl distribution Perinci-Examples), released on 2016-06-02.
+This document describes version 0.74 of Perinci::Examples (from Perl distribution Perinci-Examples), released on 2016-10-25.
 
 =head1 DESCRIPTION
 
@@ -1401,7 +1401,7 @@ Return value:  (buf)
 
 Generate sample data of various form.
 
-This function is first written to test C<Perinci::CmdLine::Lite>'s text
+This function is first written to test L<Perinci::CmdLine::Lite>'s text
 formatting rules.
 
 This function is not exported.
@@ -1449,11 +1449,11 @@ Merge two hashes.
 This function can be used to test passing nonscalar (hash) arguments.
 
 This function also tests the C<x.perinci.sub.wrapper.disable_validate_args>
-attribute so that C<Perinci::Sub::Wrapper> does not generate argument validation
-code in the wrapper. Note that by adding C<# VALIDATE_ARG> in the source code,
-the Dist::Zilla::Plugin::Rinci::Wrap already generates and embeds argument
-validation code in the source code, so duplication is not desired, thus the
-attribute.
+attribute so that L<Perinci::Sub::Wrapper> does not generate argument
+validation code in the wrapper. Note that by adding C<# VALIDATE_ARG> in the
+source code, the L<Dist::Zilla::Plugin::Rinci::Wrap> plugin already generates
+and embeds argument validation code in the source code, so duplication is not
+desired, thus the attribute.
 
 This function is not exported.
 
@@ -1489,7 +1489,7 @@ Example for result metadata property `results`.
 
 This function might return 200, 207, or 500, randomly. It will set result
 metadata property C<results> to contain per-item results. For more details, see
-the corresponding specification in C<results> property in C<Rinci::resmeta>.
+the corresponding specification in C<results> property in L<Rinci::resmeta>.
 
 This function is not exported.
 
@@ -1695,7 +1695,7 @@ Result:
 
  [
    400,
-   "Argument 'array' fails validation: Not of type decimal number",
+   "Argument 'array' fails validation: \@[0]: Not of type decimal number",
    undef,
    {},
  ]
@@ -1961,7 +1961,7 @@ it will complete from any C<in> value, but in:
 
 it can exclude C<apple> from the completion candidate.
 
-Currently the completion library C<Perinci::Sub::Complete> does not do this
+Currently the completion library L<Perinci::Sub::Complete> does not do this
 though. Perhaps there can be an option to toggle this behavior.
 
 =item * B<a2> => I<array[str]>
@@ -1998,7 +1998,7 @@ Integer with just "int" schema defined.
 
 Integer with min/xmax on the schema.
 
-A completion library (like C<Perinci::Sub::Complete>) can generate a list of
+A completion library (like L<Perinci::Sub::Complete>) can generate a list of
 completion from the low end to the high end of the range, as long as it is not
 too long.
 
@@ -2085,8 +2085,8 @@ Return value:  (any)
 This function's metadata sets C<result_naked> to true. This means function
 returns just the value (e.g. C<42>) and not with envelope (e.g. C<[200,"OK",42]>).
 However, when served over network Riap protocol, the function wrapper
-C<Perinci::Sub::Wrapper> can generate an envelope for the result, so the wrapped
-function wil still return C<[200,"OK",42]>.
+L<Perinci::Sub::Wrapper> can generate an envelope for the result, so the
+wrapped function wil still return C<[200,"OK",42]>.
 
 This function is not exported.
 
@@ -2137,8 +2137,8 @@ Return value:  (str)
 
 This function has several undescribed args.
 
-Originally added to see how peri-func-usage or C<Perinci::To::Text> will display
-the usage or documentation for this function.
+Originally added to see how peri-func-usage or L<Perinci::To::Text> will
+display the usage or documentation for this function.
 
 This function is not exported.
 
