@@ -1,7 +1,7 @@
 package Perinci::Examples::ArgsAs;
 
-our $DATE = '2016-06-02'; # DATE
-our $VERSION = '0.73'; # VERSION
+our $DATE = '2016-10-25'; # DATE
+our $VERSION = '0.74'; # VERSION
 
 use 5.010001;
 use strict;
@@ -100,7 +100,7 @@ Perinci::Examples::ArgsAs - Demonstrate various values of `args_as` function met
 
 =head1 VERSION
 
-This document describes version 0.73 of Perinci::Examples::ArgsAs (from Perl distribution Perinci-Examples), released on 2016-06-02.
+This document describes version 0.74 of Perinci::Examples::ArgsAs (from Perl distribution Perinci-Examples), released on 2016-10-25.
 
 =head1 DESCRIPTION
 
@@ -226,7 +226,7 @@ Examples:
 
 Result:
 
- [200, "OK", ["arg1", "def", "arg3", 0.5, "arg2", 20], {}]
+ [200, "OK", ["arg3", 0.5, "arg2", 20, "arg1", "def"], {}]
 
 =back
 
