@@ -1,7 +1,7 @@
 package Perinci::Examples::CmdLineSrc;
 
-our $DATE = '2016-06-02'; # DATE
-our $VERSION = '0.73'; # VERSION
+our $DATE = '2016-10-25'; # DATE
+our $VERSION = '0.74'; # VERSION
 
 use 5.010;
 use strict;
@@ -188,7 +188,7 @@ $SPEC{test_binary} = {
     summary => "Accept binary in stdin/file",
     description => <<'_',
 
-This function is like the one in `Perinci::Examples` but argument is accepted
+This function is like the one in <pm:Perinci::Examples> but argument is accepted
 via `stdin_or_files`.
 
 _
@@ -225,7 +225,7 @@ Perinci::Examples::CmdLineSrc - Examples for using cmdline_src function property
 
 =head1 VERSION
 
-This document describes version 0.73 of Perinci::Examples::CmdLineSrc (from Perl distribution Perinci-Examples), released on 2016-06-02.
+This document describes version 0.74 of Perinci::Examples::CmdLineSrc (from Perl distribution Perinci-Examples), released on 2016-10-25.
 
 =head1 FUNCTIONS
 
@@ -584,7 +584,7 @@ Return value:  (any)
 
 Accept binary in stdin/file.
 
-This function is like the one in C<Perinci::Examples> but argument is accepted
+This function is like the one in L<Perinci::Examples> but argument is accepted
 via C<stdin_or_files>.
 
 This function is not exported.
