@@ -1,7 +1,7 @@
 package Perinci::Examples::Completion;
 
-our $DATE = '2016-06-02'; # DATE
-our $VERSION = '0.73'; # VERSION
+our $DATE = '2016-10-25'; # DATE
+our $VERSION = '0.74'; # VERSION
 
 use 5.010;
 use strict;
@@ -19,6 +19,7 @@ $SPEC{fruits} = {
     v => 1.1,
     args => {
         fruits => {
+            'x.name.is_plural' => 1,
             schema => [array => of => 'str'],
             element_completion => sub {
                 my %args = @_;
@@ -29,6 +30,7 @@ $SPEC{fruits} = {
                     apple => "One a day of this and you keep the doctor away",
                     apricot => "Another fruit that starts with the letter A",
                     banana => "A tropical fruit",
+                    "butternut squash" => "Popular among babies' parents", # contain space, description contains quote
                     cherry => "Often found on cakes or drinks",
                     durian => "Lots of people hate this, but it's popular in Asia",
                 );
@@ -71,7 +73,7 @@ Perinci::Examples::Completion - More completion examples
 
 =head1 VERSION
 
-This document describes version 0.73 of Perinci::Examples::Completion (from Perl distribution Perinci-Examples), released on 2016-06-02.
+This document describes version 0.74 of Perinci::Examples::Completion (from Perl distribution Perinci-Examples), released on 2016-10-25.
 
 =for Pod::Coverage .*
 
