@@ -1,7 +1,7 @@
 package Perinci::Examples::ResultNaked;
 
-our $DATE = '2016-06-02'; # DATE
-our $VERSION = '0.73'; # VERSION
+our $DATE = '2016-10-25'; # DATE
+our $VERSION = '0.74'; # VERSION
 
 use 5.010001;
 use strict;
@@ -76,7 +76,7 @@ Perinci::Examples::ResultNaked - Demonstrate `result_naked` property
 
 =head1 VERSION
 
-This document describes version 0.73 of Perinci::Examples::ResultNaked (from Perl distribution Perinci-Examples), released on 2016-06-02.
+This document describes version 0.74 of Perinci::Examples::ResultNaked (from Perl distribution Perinci-Examples), released on 2016-10-25.
 
 =head1 DESCRIPTION
 
@@ -104,7 +104,7 @@ Examples:
 
 =item * Without the optional arg3:
 
- result_naked(arg1 => "abc", arg2 => 10); # -> ["arg2", 10, "arg1", "abc"]
+ result_naked(arg1 => "abc", arg2 => 10); # -> ["arg1", "abc", "arg2", 10]
 
 =item * With the optional arg3:
 
@@ -139,7 +139,7 @@ Examples:
 
 =item * Without the optional arg3:
 
- result_not_naked(arg1 => "abc", arg2 => 10); # -> [200, "OK", ["arg2", 10, "arg1", "abc"], {}]
+ result_not_naked(arg1 => "abc", arg2 => 10); # -> [200, "OK", ["arg1", "abc", "arg2", 10], {}]
 
 =item * With the optional arg3:
 
@@ -147,7 +147,7 @@ Examples:
 
 Result:
 
- [200, "OK", ["arg3", 0.5, "arg2", 20, "arg1", "def"], {}]
+ [200, "OK", ["arg2", 20, "arg3", 0.5, "arg1", "def"], {}]
 
 =back
 
